# &#x1F300; Pykka

_Pykka makes it easier to build concurrent applications._

[![CI](https://img.shields.io/github/workflow/status/jodal/pykka/CI)](https://github.com/jodal/pykka/actions?workflow=CI)
[![Docs](https://img.shields.io/readthedocs/pykka)](https://pykka.readthedocs.io/en/latest/)
[![Coverage](https://img.shields.io/codecov/c/gh/jodal/pykka)](https://codecov.io/gh/jodal/pykka)
[![PyPI](https://img.shields.io/pypi/v/pykka)](https://pypi.org/project/pykka/)

---

Pykka is a Python implementation of the
[actor model](https://en.wikipedia.org/wiki/Actor_model).
The actor model introduces some simple rules to control
the sharing of state and cooperation between execution units,
which makes it easier to build concurrent applications.

For a quickstart guide and a complete API reference,
see the [documentation](https://pykka.readthedocs.io/).

## Installation

Pykka requires Python 3.6 or newer.

Pykka is available from [PyPI](https://pypi.org/project/pykka/):

```
python3 -m pip install pykka
```

If you need support for Python 2.7 or 3.5, you can use Pykka 2.

## License

Pykka is copyright 2010-2021 Stein Magnus Jodal and contributors.
Pykka is licensed under the
[Apache License, Version 2.0](https://www.apache.org/licenses/LICENSE-2.0).
